@@ -192,57 +192,58 @@ int main()
    static struct debug_vars dv;
 
    static struct kvpdict kvpdict[] = {
-      { "encoders",         &tv.num_encoders },         /* threads_info */
-      { "streamers",        &tv.num_streamers },
-      { "recorders",        &tv.num_recorders },
-      { "encode_source",    &ev.encode_source },        /* encoder_vars */
-      { "sample_rate",      &ev.sample_rate },
-      { "resample_quality", &ev.resample_quality },
-      { "format",           &ev.format },
-      { "subformat",        &ev.subformat },
-      { "bit_rate",         &ev.bit_rate },
-      { "bit_rate_min",     &ev.bit_rate_min },
-      { "bit_rate_max",     &ev.bit_rate_max },
-      { "bit_width",        &ev.bit_width },
-      { "stereo",           &ev.stereo },
-      { "use_metadata",     &ev.use_metadata },
-      { "encode_quality",   &ev.encode_quality },
-      { "speex_mode",       &ev.speex_mode },
-      { "speex_quality",    &ev.speex_quality },
-      { "speex_complexity", &ev.speex_complexity },
-      { "filename",         &ev.filename },
-      { "offset",           &ev.offset },
-      { "custom_meta",      &ev.custom_meta },
-      { "custom_meta_lat1", &ev.custom_meta_lat1 },
-      { "artist",           &ev.artist },
-      { "title",            &ev.title },
-      { "album",            &ev.album },
-      { "artist_title_lat1", &ev.artist_title_lat1 },
-      { "freeformat_mp3",   &ev.freeformat_mp3 },
-      { "stream_source",    &sv.stream_source },        /* streamer_vars */
-      { "server_type",      &sv.server_type },
-      { "host",             &sv.host },
-      { "port",             &sv.port },
-      { "mount",            &sv.mount },
-      { "login",            &sv.login },
-      { "password",         &sv.password },
-      { "dj_name",          &sv.dj_name },
-      { "listen_url",       &sv.listen_url },
-      { "description",      &sv.description },
-      { "genre",            &sv.genre },
-      { "irc",              &sv.irc },
-      { "aim",              &sv.aim },
-      { "icq",              &sv.icq },
-      { "make_public",      &sv.make_public },
-      { "record_source",    &rv.record_source },        /* recorder_vars */
-      { "record_folder",    &rv.record_folder },
-      { "pause_button",     &rv.pause_button },
-      { "auto_pause_button",&rv.auto_pause_button },
-      { "timeout_duration", &dv.timeout_duration },
-      { "command",  &uv.command},
-      { "dev_type", &uv.dev_type},
-      { "tab_id",   &uv.tab_id},
-      { NULL } };
+      { "encoders",         &tv.num_encoders, NULL },         /* threads_info */
+      { "streamers",        &tv.num_streamers, NULL },
+      { "recorders",        &tv.num_recorders, NULL },
+      { "encode_source",    &ev.encode_source, NULL },        /* encoder_vars */
+      { "sample_rate",      &ev.sample_rate, NULL },
+      { "resample_quality", &ev.resample_quality, NULL },
+      { "format",           &ev.format, NULL },
+      { "subformat",        &ev.subformat, NULL },
+      { "bit_rate",         &ev.bit_rate, NULL },
+      { "bit_rate_min",     &ev.bit_rate_min, NULL },
+      { "bit_rate_max",     &ev.bit_rate_max, NULL },
+      { "bit_width",        &ev.bit_width, NULL },
+      { "stereo",           &ev.stereo, NULL },
+      { "use_metadata",     &ev.use_metadata, NULL },
+      { "encode_quality",   &ev.encode_quality, NULL },
+      { "speex_mode",       &ev.speex_mode, NULL },
+      { "speex_quality",    &ev.speex_quality, NULL },
+      { "speex_complexity", &ev.speex_complexity, NULL },
+      { "filename",         &ev.filename, NULL },
+      { "offset",           &ev.offset, NULL },
+      { "custom_meta",      &ev.custom_meta, NULL },
+      { "custom_meta_lat1", &ev.custom_meta_lat1, NULL },
+      { "artist",           &ev.artist, NULL },
+      { "title",            &ev.title, NULL },
+      { "album",            &ev.album, NULL },
+      { "artist_title_lat1", &ev.artist_title_lat1, NULL },
+      { "freeformat_mp3",   &ev.freeformat_mp3, NULL },
+      { "stream_source",    &sv.stream_source, NULL },        /* streamer_vars */
+      { "server_type",      &sv.server_type, NULL },
+      { "host",             &sv.host, NULL },
+      { "port",             &sv.port, NULL },
+      { "mount",            &sv.mount, NULL },
+      { "login",            &sv.login, NULL },
+      { "password",         &sv.password, NULL },
+      { "useragent",        &sv.useragent, NULL },
+      { "dj_name",          &sv.dj_name, NULL },
+      { "listen_url",       &sv.listen_url, NULL },
+      { "description",      &sv.description, NULL },
+      { "genre",            &sv.genre, NULL },
+      { "irc",              &sv.irc, NULL },
+      { "aim",              &sv.aim, NULL },
+      { "icq",              &sv.icq, NULL },
+      { "make_public",      &sv.make_public, NULL },
+      { "record_source",    &rv.record_source, NULL },        /* recorder_vars */
+      { "record_folder",    &rv.record_folder, NULL },
+      { "pause_button",     &rv.pause_button, NULL },
+      { "auto_pause_button",&rv.auto_pause_button, NULL },
+      { "timeout_duration", &dv.timeout_duration, NULL },
+      { "command",  &uv.command, NULL},
+      { "dev_type", &uv.dev_type, NULL},
+      { "tab_id",   &uv.tab_id, NULL},
+      { NULL, NULL, NULL } };
 
    static struct commandmap commandmap[] = {
       { "threads_init", threads_init, &tv },
@@ -265,7 +266,7 @@ int main()
       { "debug", debug_command, NULL },
       { "nodebug", debug_command, NULL },
       { "set_timeout", debug_command, &dv },
-      { NULL } }; 
+      { NULL, NULL, NULL } }; 
 
    setenv("LC_ALL", "C", 1);
    setlocale(LC_ALL, "C");
